pub fn ensure_intrinsic_gas_tempo_tx(
tx: &TempoPooledTransaction,
spec: TempoHardfork,
) -> Result<(), InvalidPoolTransactionError>Expand description
Ensures that gas limit of the transaction exceeds the intrinsic gas of the transaction.
pub fn ensure_intrinsic_gas_tempo_tx(
tx: &TempoPooledTransaction,
spec: TempoHardfork,
) -> Result<(), InvalidPoolTransactionError>Ensures that gas limit of the transaction exceeds the intrinsic gas of the transaction.